@@ -132,6 +132,47 @@ public class WSDL2JavaMojo extends AbstractMojo {
         return options;
     }
     
+    private void mergeOptions(List<WsdlOption> options) {
+        File outputDirFile = testSourceRoot == null ? sourceRoot : testSourceRoot;
+        for (WsdlOption o : wsdlOptions) {
+            if (o.getOutputDir() == null) {
+                o.setOutputDir(outputDirFile);
+            }
+            
+            File file = new File(o.getWsdl());
+            if (!file.exists()) {
+                file = new File(project.getBasedir(), o.getWsdl());
+            }
+            if (file.exists()) {
+                file = file.getAbsoluteFile();
+                for (WsdlOption o2 : options) {
+                    File file2 = null;
+                    try {
+                        URI uri = new URI(o2.getWsdl());
+                        if (uri.isAbsolute()) {
+                            file2 = new File(uri);
+                        }
+                    } catch (Exception e) {
+                        //ignore
+                    }
+                    if (file2 == null || !file2.exists()) {
+                        file2 = new File(o2.getWsdl());
+                    }
+                    if (file2 == null || !file2.exists()) {
+                        file2 = new File(project.getBasedir(), o2.getWsdl());
+                    }
+                    if (file2.exists() 
+                        && file2.getAbsoluteFile().equals(file)) {
+                        o.getExtraargs().addAll(0, o2.getExtraargs());
+                        options.remove(o2);
+                        break;
+                    }
+                }
+            }
+            options.add(0, o);
+        }        
+    }
+    
     public void execute() throws MojoExecutionException {
         if (includes == null) {
             includes = new String[] {"*.wsdl"};
@@ -150,26 +191,7 @@ public class WSDL2JavaMojo extends AbstractMojo {
         }
 
         if (wsdlOptions != null) {
-            File outputDirFile = testSourceRoot == null ? sourceRoot : testSourceRoot;
-            for (WsdlOption o : wsdlOptions) {
-                if (o.getOutputDir() == null) {
-                    o.setOutputDir(outputDirFile);
-                }
-                
-                File file = new File(project.getBasedir(), o.getWsdl());                
-                if (file.exists()) {
-                    for (WsdlOption o2 : options) {
-                        File file2 = new File(o2.getWsdl());
-                        if (file2.exists() 
-                            && file2.equals(file)) {
-                            o.getExtraargs().addAll(0, o2.getExtraargs());
-                            options.remove(o2);
-                            break;
-                        }
-                    }
-                }
-                options.add(o);
-            }
+            mergeOptions(options);
         }
         wsdlOptions = options.toArray(new WsdlOption[options.size()]);
 
@@ -183,14 +205,19 @@ public class WSDL2JavaMojo extends AbstractMojo {
 
         try {
             urlList.add(classesDir.toURI().toURL());
+            if (!useCompileClasspath) {
+                urlList.add(new File(project.getBuild().getOutputDirectory()).toURI().toURL());
+            }
         } catch (MalformedURLException e) {
             //ignore
         }
 
         buf.append(classesDir.getAbsolutePath());
         buf.append(File.pathSeparatorChar);
-
-
+        if (!useCompileClasspath) {
+            buf.append(project.getBuild().getOutputDirectory());
+            buf.append(File.pathSeparatorChar);
+        }
         List artifacts = useCompileClasspath ? project.getCompileArtifacts() : project.getTestArtifacts();
         for (Artifact a : CastUtils.cast(artifacts, Artifact.class)) {
             try {
@@ -210,6 +237,8 @@ public class WSDL2JavaMojo extends AbstractMojo {
         URLClassLoader loader = new URLClassLoader(urlList.toArray(new URL[urlList.size()]),
                                                    origContext);
         String newCp = buf.toString();
+        
+        getLog().debug("Classpath: " + urlList.toString());
 
         //with some VM's, creating an XML parser (which we will do to parse wsdls)
         //will set some system properties that then interferes with mavens 
@@ -249,6 +278,7 @@ public class WSDL2JavaMojo extends AbstractMojo {
                 }
             }
             System.getProperties().putAll(origProps);
+            org.apache.cxf.tools.wsdlto.core.PluginLoader.unload();
         }
         if (project != null && sourceRoot != null && sourceRoot.exists()) {
             project.addCompileSourceRoot(sourceRoot.getAbsolutePath());
@@ -280,11 +310,13 @@ public class WSDL2JavaMojo extends AbstractMojo {
         if (doneFileName.startsWith(basedir.toString())) {
             doneFileName = doneFileName.substring(basedir.toString().length());
         }
+
+        // If URL to WSDL, replace ? and & since they're invalid chars for file names
+        // Not to mention slashes.
         
         doneFileName = doneFileName.replace('?', '_')
-            .replace('&', '_').replace('/', '_').replace('\\', '_');
+            .replace('&', '_').replace('/', '_').replace('\\', '_').replace(':', '_'); 
         
-        // If URL to WSDL, replace ? and & since they're invalid chars for file names
         File doneFile =
             new File(markerDirectory, "." + doneFileName + ".DONE");
         
