@@ -23,6 +23,7 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.MalformedURLException;
+import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLClassLoader;
@@ -34,6 +35,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.StringTokenizer;
+import java.util.jar.Attributes;
+import java.util.jar.JarFile;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
@@ -62,11 +65,12 @@ import com.sun.tools.xjc.api.XJC;
 import org.apache.cxf.Bus;
 import org.apache.cxf.bus.CXFBusFactory;
 import org.apache.cxf.common.i18n.Message;
-import org.apache.cxf.common.i18n.UncheckedException;
 import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.common.util.StringUtils;
 import org.apache.cxf.endpoint.Client;
 import org.apache.cxf.endpoint.ClientImpl;
+import org.apache.cxf.endpoint.EndpointImplFactory;
+import org.apache.cxf.endpoint.SimpleEndpointImplFactory;
 import org.apache.cxf.helpers.FileUtils;
 import org.apache.cxf.jaxb.JAXBDataBinding;
 import org.apache.cxf.resource.URIResolver;
@@ -74,15 +78,20 @@ import org.apache.cxf.service.Service;
 import org.apache.cxf.service.factory.ServiceConstructionException;
 import org.apache.cxf.service.model.SchemaInfo;
 import org.apache.cxf.service.model.ServiceInfo;
-import org.apache.tools.ant.Project;
-import org.apache.tools.ant.types.DirSet;
-import org.apache.tools.ant.types.FileSet;
-import org.apache.tools.ant.types.Path;
 /**
+ * This class reads a WSDL and creates a dynamic client from it.
  * 
+ * Use {@link #newInstance} to obtain an instance, and then
+ * {@link #createClient(String)} (or other overloads) to create a client.
+ * 
+ * It uses the JAXB data binding. It does not set up complex interceptors for 
+ * features such as attachments. 
+ * See {@link org.apache.cxf.jaxws.endpoint.dynamic.JaxWsDynamicClientFactory}
+ * for an alternative that sets up JAX-WS endpoints.
  *
+ * This class may be subclassed to allow for other endpoints or behaviors.
  */
-public final class DynamicClientFactory {
+public class DynamicClientFactory {
 
     private static final Logger LOG = LogUtils.getL7dLogger(DynamicClientFactory.class);
 
@@ -94,9 +103,13 @@ public final class DynamicClientFactory {
     
     private Map<String, Object> jaxbContextProperties;
     
-    private DynamicClientFactory(Bus bus) {
+    protected DynamicClientFactory(Bus bus) {
         this.bus = bus;
     }
+    
+    protected EndpointImplFactory getEndpointImplFactory() {
+        return SimpleEndpointImplFactory.getSingleton();
+    }
 
     public void setTemporaryDirectory(String dir) {
         tmpdir = dir;
@@ -180,7 +193,8 @@ public final class DynamicClientFactory {
         }
         URL u = composeUrl(wsdlUrl);
         LOG.log(Level.FINE, "Creating client from URL " + u.toString());
-        ClientImpl client = new ClientImpl(bus, u, service, port);
+        ClientImpl client = new ClientImpl(bus, u, service, port,
+                                           getEndpointImplFactory());
 
         Service svc = client.getEndpoint().getService();
         //all SI's should have the same schemas
@@ -235,16 +249,15 @@ public final class DynamicClientFactory {
         if (!classes.mkdir()) {
             throw new IllegalStateException("Unable to create working directory " + src.getPath());
         }
-        Project project = new Project();
-        project.setBaseDir(new File(tmpdir));
-        Path classPath = new Path(project);
-        setupClasspath(classPath, classLoader);
-        Path srcPath = new Path(project);
-        FileSet fileSet = new FileSet();
-        fileSet.setDir(src);
-        srcPath.addFileset(fileSet);
+        StringBuilder classPath = new StringBuilder();
+        try {
+            setupClasspath(classPath, classLoader);
+        } catch (Exception ex) {
+            throw new RuntimeException(ex);
+        }
         
-        if (!compileJavaSrc(classPath, srcPath, classes.toString())) {
+        List<File> srcFiles = FileUtils.getFilesRecurse(src, ".+\\.java$"); 
+        if (!compileJavaSrc(classPath.toString(), srcFiles, classes.toString())) {
             LOG.log(Level.SEVERE , new Message("COULD_NOT_COMPILE_SRC", LOG, wsdlUrl).toString());
         }
         FileUtils.removeDir(src);
@@ -290,6 +303,7 @@ public final class DynamicClientFactory {
         return client;
     }
 
+    @SuppressWarnings("deprecation")
     private void addBindingFiles(List<String> bindingFiles, SchemaCompiler compiler) {
         if (bindingFiles != null) {
             for (String s : bindingFiles) {
@@ -299,7 +313,7 @@ public final class DynamicClientFactory {
                     InputSource is = new InputSource(ins);
                     is.setSystemId(url.toString());
                     is.setPublicId(url.toString());
-                    compiler.parseSchema(is);
+                    compiler.getOptions().addBindFile(is);
                 } catch (IOException e) {
                     throw new RuntimeException(e);
                 }
@@ -352,6 +366,7 @@ public final class DynamicClientFactory {
         
     }
 
+    @SuppressWarnings("deprecation")
     private void addSchemas(String wsdlUrl, Collection<SchemaInfo> schemas, SchemaCompiler compiler) {
         int num = 1;
         for (SchemaInfo schema : schemas) {
@@ -360,6 +375,13 @@ public final class DynamicClientFactory {
             if (StringUtils.isEmpty(key)) {
                 key = wsdlUrl + "#types" + num;
             }
+
+            //For JAXB 2.1.8
+            InputSource is = new InputSource((InputStream)null);
+            is.setSystemId(key);
+            is.setPublicId(key);
+            compiler.getOptions().addGrammar(is);
+
             compiler.parseSchema(key, el);
             num++;
         }
@@ -407,28 +429,64 @@ public final class DynamicClientFactory {
         this.simpleBindingEnabled = simpleBindingEnabled;
     }
 
-    public boolean compileJavaSrc(Path classPath, Path srcPath, String dest) {
-        String[] srcList = srcPath.list();        
-        String[] javacCommand = new String[srcList.length + 7];
+    static boolean compileJavaSrc(String classPath, List<File> srcList, String dest) {
+        String[] javacCommand = new String[srcList.size() + 7];
         
         javacCommand[0] = "javac";
         javacCommand[1] = "-classpath";
-        javacCommand[2] = classPath.toString();        
+        javacCommand[2] = classPath;        
         javacCommand[3] = "-d";
-        javacCommand[4] = dest.toString();
+        javacCommand[4] = dest;
         javacCommand[5] = "-target";
         javacCommand[6] = "1.5";
         
-        for (int i = 0; i < srcList.length; i++) {
-            javacCommand[7 + i] = srcList[i];            
+        int i = 7;
+        for (File f : srcList) {
+            javacCommand[i++] = f.getAbsolutePath();            
         }
-        org.apache.cxf.tools.util.Compiler javaCompiler 
-            = new org.apache.cxf.tools.util.Compiler();
+        org.apache.cxf.common.util.Compiler javaCompiler 
+            = new org.apache.cxf.common.util.Compiler();
         
         return javaCompiler.internalCompile(javacCommand, 7); 
     }
+    
+    static void addClasspathFromManifest(StringBuilder classPath, File file) 
+        throws URISyntaxException, IOException {
+        
+        JarFile jar = new JarFile(file);
+        Attributes attr = null;
+        if (jar.getManifest() != null) {
+            attr = jar.getManifest().getMainAttributes();
+        }
+        if (attr != null) {
+            String cp = attr.getValue("Class-Path");
+            while (cp != null) {
+                String fileName = cp;
+                int idx = fileName.indexOf(' ');
+                if (idx != -1) {
+                    fileName = fileName.substring(0, idx);
+                    cp =  cp.substring(idx + 1).trim();
+                } else {
+                    cp = null;
+                }
+                URI uri = new URI(fileName);
+                File f2;
+                if (uri.isAbsolute()) {
+                    f2 = new File(uri);
+                } else {
+                    f2 = new File(file, fileName);
+                }
+                if (f2.exists()) {
+                    classPath.append(f2.getAbsolutePath());
+                    classPath.append(System.getProperty("path.separator"));
+                }
+            }
+        }         
+    }
 
-    static void setupClasspath(Path classPath, ClassLoader classLoader) {
+    static void setupClasspath(StringBuilder classPath, ClassLoader classLoader)
+        throws URISyntaxException, IOException {
+        
         ClassLoader scl = ClassLoader.getSystemClassLoader();        
         ClassLoader tcl = classLoader;
         do {
@@ -439,20 +497,22 @@ public final class DynamicClientFactory {
                 }
                 for (URL url : urls) {
                     if (url.getProtocol().startsWith("file")) {
-                        try {
-                            File file = new File(url.toURI().getPath());
-                            if (file.isDirectory()) {
-                                DirSet ds = new DirSet();
-                                ds.setFile(file);
-                                classPath.addDirset(ds);
-                            } else {
-                                FileSet fs = new FileSet();
-                                fs.setFile(file);
-                                classPath.addFileset(fs);
-                            }
-                        } catch (URISyntaxException e) {
-                            throw new UncheckedException(e);
-                        }
+                        File file; 
+                        try { 
+                            file = new File(url.toURI().getPath()); 
+                        } catch (URISyntaxException urise) { 
+                            file = new File(url.getPath()); 
+                        } 
+
+                        if (file.exists()) { 
+                            classPath.append(file.getAbsolutePath()) 
+                                .append(System 
+                                        .getProperty("path.separator")); 
+
+                            if (file.getName().endsWith(".jar")) { 
+                                addClasspathFromManifest(classPath, file); 
+                            }                         
+                        }     
                     }
                 }
             }
@@ -460,7 +520,7 @@ public final class DynamicClientFactory {
             if (null == tcl) {
                 break;
             }
-        } while(!tcl.equals(scl));
+        } while(!tcl.equals(scl.getParent()));
     }
 
     private URL composeUrl(String s) {
