@@ -20,8 +20,12 @@
 package org.apache.cxf.transport.http;
 
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.HttpURLConnection;
+import java.net.ServerSocket;
+import java.net.URL;
+import java.security.Principal;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Enumeration;
@@ -32,6 +36,7 @@ import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
+import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.xml.namespace.QName;
@@ -48,12 +53,14 @@ import org.apache.cxf.helpers.HttpHeaderHelper;
 import org.apache.cxf.io.AbstractWrappedOutputStream;
 import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.Message;
+import org.apache.cxf.security.SecurityContext;
 import org.apache.cxf.service.model.EndpointInfo;
 import org.apache.cxf.transport.AbstractDestination;
 import org.apache.cxf.transport.AbstractMultiplexDestination;
 import org.apache.cxf.transport.Conduit;
 import org.apache.cxf.transport.ConduitInitiator;
 import org.apache.cxf.transport.http.policy.PolicyUtils;
+import org.apache.cxf.transport.https.SSLUtils;
 import org.apache.cxf.transports.http.configuration.HTTPServerPolicy;
 import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.apache.cxf.ws.policy.Assertor;
@@ -70,7 +77,7 @@ public abstract class AbstractHTTPDestination extends AbstractMultiplexDestinati
     public static final String HTTP_RESPONSE = "HTTP.RESPONSE";
     public static final String HTTP_CONTEXT = "HTTP.CONTEXT";
     public static final String PROTOCOL_HEADERS_CONTENT_TYPE = Message.CONTENT_TYPE.toLowerCase();
-    
+        
     private static final Logger LOG = LogUtils.getL7dLogger(AbstractHTTPDestination.class);
     
     private static final long serialVersionUID = 1L;
@@ -90,7 +97,7 @@ public abstract class AbstractHTTPDestination extends AbstractMultiplexDestinati
      * @param b the associated Bus
      * @param ci the associated conduit initiator
      * @param ei the endpoint info of the destination 
-     * @param dp ture for adding the default port if it is missing
+     * @param dp true for adding the default port if it is missing
      * @throws IOException
      */    
     public AbstractHTTPDestination(Bus b,
@@ -126,9 +133,10 @@ public abstract class AbstractHTTPDestination extends AbstractMultiplexDestinati
                 try {
                     String authDecoded = new String(Base64Utility.decode(authEncoded));
                     String authInfo[] = authDecoded.split(":");
-                    String username = authInfo[0];
-                    String password = authInfo[1];
-                    
+                    String username = (authInfo.length > 0) ? authInfo[0] : "";
+                    // Below line for systems that blank out password after authentication;
+                    // see CXF-1495 for more info
+                    String password = (authInfo.length > 1) ? authInfo[1] : "";
                     AuthorizationPolicy policy = new AuthorizationPolicy();
                     policy.setUserName(username);
                     policy.setPassword(password);
@@ -164,6 +172,13 @@ public abstract class AbstractHTTPDestination extends AbstractMultiplexDestinati
         Exchange ex = message.getExchange();
         return ex == null ? false : ex.isOneWay();
     }
+    
+    /**
+     * @return the associated conduit initiator
+     */
+    protected ConduitInitiator getConduitInitiator() {
+        return conduitInitiator;
+    }
 
     /**
      * Copy the request headers into the message.
@@ -226,12 +241,89 @@ public abstract class AbstractHTTPDestination extends AbstractMultiplexDestinati
         }
     }
     
+    protected void setupMessage(Message inMessage,
+                                  final ServletContext context, 
+                                  final HttpServletRequest req, 
+                                  final HttpServletResponse resp) throws IOException {
+
+        inMessage.setContent(InputStream.class, req.getInputStream());
+        inMessage.put(HTTP_REQUEST, req);
+        inMessage.put(HTTP_RESPONSE, resp);
+        inMessage.put(HTTP_CONTEXT, context);
+        inMessage.put(Message.HTTP_REQUEST_METHOD, req.getMethod());
+        inMessage.put(Message.REQUEST_URI, req.getRequestURI());
+        String contextPath = req.getContextPath();
+        if (contextPath == null) {
+            contextPath = "";
+        }
+        inMessage.put(Message.PATH_INFO, contextPath + req.getPathInfo());
+        
+        // work around a bug with Jetty which results in the character
+        // encoding not being trimmed correctly.
+        String enc = req.getCharacterEncoding();
+        if (enc != null && enc.endsWith("\"")) {
+            enc = enc.substring(0, enc.length() - 1);
+        }
+        String normalizedEncoding = HttpHeaderHelper.mapCharset(enc);
+        if (normalizedEncoding == null) {
+            String m = new org.apache.cxf.common.i18n.Message("INVALID_ENCODING_MSG",
+                                                              LOG, enc).toString();
+            LOG.log(Level.WARNING, m);
+            throw new IOException(m);   
+        }
+        
+        inMessage.put(Message.ENCODING, normalizedEncoding);
+        
+        inMessage.put(Message.QUERY_STRING, req.getQueryString());
+        inMessage.put(Message.CONTENT_TYPE, req.getContentType());
+        inMessage.put(Message.ACCEPT_CONTENT_TYPE, req.getHeader("Accept"));
+        String basePath = getBasePath(contextPath);
+        if (!StringUtils.isEmpty(basePath)) {
+            inMessage.put(Message.BASE_PATH, basePath);
+        }
+        inMessage.put(Message.FIXED_PARAMETER_ORDER, isFixedParameterOrder());
+        inMessage.put(Message.ASYNC_POST_RESPONSE_DISPATCH, Boolean.TRUE);
+        inMessage.put(SecurityContext.class, new SecurityContext() {
+            public Principal getUserPrincipal() {
+                return req.getUserPrincipal();
+            }
+            public boolean isUserInRole(String role) {
+                return req.isUserInRole(role);
+            }
+        });
+        
+        setHeaders(inMessage);
+        
+        SSLUtils.propogateSecureSession(req, inMessage);
+    }
+    
+    protected String getBasePath(String contextPath) throws IOException {
+        if (StringUtils.isEmpty(endpointInfo.getAddress())) {
+            return "";
+        }
+        return new URL(endpointInfo.getAddress()).getPath();
+    }
+    
     protected static EndpointInfo getAddressValue(EndpointInfo ei) {       
         return getAddressValue(ei, true);
     } 
     
     protected static EndpointInfo getAddressValue(EndpointInfo ei, boolean dp) {       
         if (dp) {
+            
+            String eiAddress = ei.getAddress();
+            if (eiAddress == null) {
+                try {
+                    ServerSocket s = new ServerSocket(0);
+                    ei.setAddress("http://localhost:" + s.getLocalPort());
+                    s.close();
+                    return ei;
+                } catch (IOException ex) {
+                    // problem allocating a random port, go to the default one
+                    ei.setAddress("http://localhost");
+                }
+            }
+            
             String addr = StringUtils.addDefaultPortIfMissing(ei.getAddress());
             if (addr != null) {
                 ei.setAddress(addr);
